/***************************************************************************//**
*   @file   cn0188.c
*   @brief  Header file of CN0188 Driver for Microblaze processor.
*   @author DBogdan (dragos.bogdan@analog.com)
*
********************************************************************************
* Copyright 2012(c) Analog Devices, Inc.
*
* All rights reserved.
*
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions are met:
*  - Redistributions of source code must retain the above copyright
*    notice, this list of conditions and the following disclaimer.
*  - Redistributions in binary form must reproduce the above copyright
*    notice, this list of conditions and the following disclaimer in
*    the documentation and/or other materials provided with the
*    distribution.
*  - Neither the name of Analog Devices, Inc. nor the names of its
*    contributors may be used to endorse or promote products derived
*    from this software without specific prior written permission.
*  - The use of this software may or may not infringe the patent rights
*    of one or more patent holders.  This license does not release you
*    from the requirement that you obtain separate licenses from these
*    patent holders to use this software.
*  - Use of the software either in source or binary form, must be run
*    on or directly connected to an Analog Devices Inc. component.
*
* THIS SOFTWARE IS PROVIDED BY ANALOG DEVICES "AS IS" AND ANY EXPRESS OR IMPLIED
* WARRANTIES, INCLUDING, BUT NOT LIMITED TO, NON-INFRINGEMENT, MERCHANTABILITY
* AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
* IN NO EVENT SHALL ANALOG DEVICES BE LIABLE FOR ANY DIRECT, INDIRECT,
* INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
* LIMITED TO, INTELLECTUAL PROPERTY RIGHTS, PROCUREMENT OF SUBSTITUTE GOODS OR
* SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
* CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
* OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
* OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*
********************************************************************************
*   SVN Revision: 468
*******************************************************************************/
#ifndef _CN0188_H_
#define _CN0188_H_
#ifdef CN0188_GLOBALS
    #define CN0188_EXT extern volatile
#else
    #define CN0188_EXT volatile
#endif

/*****************************************************************************/
/* Include Files                                                             */
/*****************************************************************************/
#include "xil_types.h"
#include "xparameters.h"

/*****************************************************************************/
/* Types Declarations                                                        */
/*****************************************************************************/
typedef union _uCProbeDataUnion
{
    char            chData;
    unsigned char   uchData;
    short           siData;
    unsigned short  usiData;
    int             iData;
    unsigned int    uiData;
    float           fData;
}uCProbeDataUnion;

/******************************************************************************/
/* SPI Configuration                                                          */
/******************************************************************************/
#define CN0188_SPI          XPAR_AXI_SPI_0_BASEADDR

/******************************************************************************/
/* AD7171                                                                     */
/******************************************************************************/
#define AD7171_DEFAULT_PATTERN  0x5     // Default pattern which indicates that
                                        // the serial transfer was performed correctly.
/* AD7171 Status Bits */
#define AD7171_STATUS_RDY   (1 << 7)    // Ready bit.
#define AD7171_STATUS_ERR   (1 << 5)    // Error bit.
#define AD7171_STATUS_ID1   (1 << 4)    // ID bit 1.
#define AD7171_STATUS_ID0   (1 << 3)    // ID bit 0.
#define AD7171_STATUS_PAT2  (1 << 2)    // Pattern bit 2.
#define AD7171_STATUS_PAT1  (1 << 1)    // Pattern bit 1.
#define AD7171_STATUS_PAT0  (1 << 0)    // Pattern bit 0.

/******************************************************************************/
/* Monitored variables declarations                                           */
/******************************************************************************/
CN0188_EXT uCProbeDataUnion CN0188_data[3]; // Used to store the values for uC-Probe communication.

/******************************************************************************/
/* Functions Prototypes                                                       */
/******************************************************************************/
int CN0188_Init(void);              // Initializes the communication with the device.
int CN0188_UpdateParameters(void);  // Updates the device's monitored and controlled parameters.
#endif /* CN0188_H_ */
